GlyCONFORMERS
=============

Info
#####

**GlyCONFORMERS** is a Python package that assigns conformer strings to N-glycan conformers, based on their torsion angle values.

Documentation
#############
See documentation https://glyconformer.readthedocs.io/en/latest/index.html


Usage
######

An example_dataset is given, which can be analysed with the main-analysis.ipynb and DimRed jupyter-notebooks.

Installation
##############

To use GlyCONFORMER, first install it using pip:

.. code-block:: console

    $ pip install GlyCONFORMER
